@@ -1,7 +1,12 @@
 require 'common'
 require 'net/ssh/config'
+require 'pathname'
 
 class TestConfig < Test::Unit::TestCase
+  def test_home_should_be_absolute_path
+    assert Pathname.new(ENV['HOME']).absolute?
+  end
+
   def test_load_for_non_existant_file_should_return_empty_hash
     bogus_file = File.expand_path("/bogus/file")
     File.expects(:readable?).with(bogus_file).returns(false)
@@ -111,6 +116,24 @@ class TestConfig < Test::Unit::TestCase
     assert_equal '2G', config['rekeylimit']
     assert_equal 1980, config['port']
   end
+
+  def test_load_wildcar_with_substitutes
+    config = Net::SSH::Config.load(config(:substitutes), "toto")
+    net_ssh = Net::SSH::Config.translate(config)
+    assert_equal 'toto', net_ssh[:host_name]
+  end
+
+  def test_load_sufix_with_substitutes
+    config = Net::SSH::Config.load(config(:substitutes), "test")
+    net_ssh = Net::SSH::Config.translate(config)
+    assert_equal 'test.sufix', net_ssh[:host_name]
+  end
+
+  def test_load_prefix_and_sufix_with_substitutes
+    config = Net::SSH::Config.load(config(:substitutes), "1234")
+    net_ssh = Net::SSH::Config.translate(config)
+    assert_equal 'prefix.1234.sufix', net_ssh[:host_name]
+  end
   
   private
 
